@@ -112,18 +112,15 @@ class Data_inegrator:
 
                 epoch += 1
                 # Do an epoch on the training set.
-                try:
-                    for patient_train_batch in self.xy_train_dataloader:
-                        field0_batch, field1_batch = patient_train_batch['FIELD0'], patient_train_batch['FIELD1']
-                        # If for some reason the batch has mor dimensions than expected, squeeze it.
-                        if len(field0_batch.shape) > 2:
-                            field0_batch, field1_batch = patient_train_batch['FIELD0'].squeeze(), patient_train_batch[
-                                'FIELD1'].squeeze()
 
-                        train_step_function(field0_batch, field1_batch)
-                except Exception:
-                    print('hi')
+                for patient_train_batch in self.xy_train_dataloader:
+                    field0_batch, field1_batch = patient_train_batch['FIELD0'], patient_train_batch['FIELD1']
+                    # If for some reason the batch has mor dimensions than expected, squeeze it.
+                    if len(field0_batch.shape) > 2:
+                        field0_batch, field1_batch = patient_train_batch['FIELD0'].squeeze(), patient_train_batch[
+                            'FIELD1'].squeeze()
 
+                    train_step_function(field0_batch, field1_batch)
                 # Do validation
                 total_validation_loss_per_epoch = 0
                 with torch.no_grad():
