@@ -24,11 +24,11 @@ class patient_samples_single_tp():
 
 
 class patient_dataset(Dataset):
-    def __init__(self, otu_df, mapping_table, patient_id_name, time_name, sample_type_name=None,matching_fn=None, transform=None):
+    def __init__(self, otu_df, mapping_table, patient_id_name, time_name, sample_type_name=None, matching_fn=None,
+                 transform=None):
         if matching_fn is None:
-            matching_fn= lambda x,y :x==y
+            matching_fn = lambda x, y: x == y
 
-        self.matching_fn=matching_fn
         self.dict_retrieval_flag = 1
         self.transform = transform
         patients_list = []
@@ -54,20 +54,20 @@ class patient_dataset(Dataset):
 
             for patient_id in all_unique_patient_ids:
 
-                field_0_unique_tp,field_1_unique_tp=[specific_mapping_table[specific_mapping_table[specific_patient_id_name]==patient_id][time] for
-                            specific_mapping_table,specific_patient_id_name, time in
-                            zip(mapping_table,patient_id_name,time_name)]
-                matching_tp_list=self._find_matches(field_0_unique_tp,field_1_unique_tp)
+                field_0_unique_tp, field_1_unique_tp = [
+                    specific_mapping_table[specific_mapping_table[specific_patient_id_name] == patient_id][time] for
+                    specific_mapping_table, specific_patient_id_name, time in
+                    zip(mapping_table, patient_id_name, time_name)]
+                matching_tp_list = self._find_matches(field_0_unique_tp, field_1_unique_tp, matching_fn)
 
-
-                for matching_field_zero_tp,matching_field_one_tp in matching_tp_list:
+                for matching_field_zero_tp, matching_field_one_tp in matching_tp_list:
                     patient_dict = {}
                     for i, (specific_otu, specific_mapping_table, patient_col_name, tp_col_name) in enumerate(
                             zip(otu_df, mapping_table, patient_id_name, time_name)):
                         if i == 0 and matching_field_zero_tp is not None:
                             patient_dict['FIELD0'] = specific_otu[
-                            (specific_mapping_table[patient_col_name] == patient_id) & (specific_mapping_table[
-                                                                                            tp_col_name] == matching_field_zero_tp)]
+                                (specific_mapping_table[patient_col_name] == patient_id) & (specific_mapping_table[
+                                                                                                tp_col_name] == matching_field_zero_tp)]
 
                         if i == 1 and matching_field_one_tp is not None:
                             patient_dict['FIELD1'] = specific_otu[
@@ -76,22 +76,22 @@ class patient_dataset(Dataset):
 
                     if bool(patient_dict):  # check if dictionary is not empty, which means that there is no samples
                         # for the given patient_id and tp.
-                        patient_dict.update({'ID': patient_id, 'TP': [matching_field_zero_tp,matching_field_one_tp]})
+                        patient_dict.update({'ID': patient_id, 'TP': [matching_field_zero_tp, matching_field_one_tp]})
                     patients_list.append(patient_samples_single_tp(patient_dict))
 
         self.patients = patients_list
 
-
-    def _find_matches(self,first_field_list,second_field_list):
-        matching_couples=[]
-        second_field_iterator=second_field_list
-        first_field_iterator=first_field_list
+    @staticmethod
+    def _find_matches(first_field_list, second_field_list, matching_fn):
+        matching_couples = []
+        second_field_iterator = second_field_list
+        first_field_iterator = first_field_list
         for first_field in first_field_list:
             for second_field in second_field_iterator:
-                if self.matching_fn(first_field,second_field):
-                    matching_couples.append((first_field,second_field))
-                    second_field_iterator=[item for item in second_field_iterator if item != second_field]
-                    first_field_iterator=[item for item in first_field_iterator if item != first_field]
+                if matching_fn(first_field, second_field):
+                    matching_couples.append((first_field, second_field))
+                    second_field_iterator = [item for item in second_field_iterator if item != second_field]
+                    first_field_iterator = [item for item in first_field_iterator if item != first_field]
                     break
                 else:
                     pass
@@ -99,17 +99,11 @@ class patient_dataset(Dataset):
         for first_field in first_field_iterator:
             matching_couples.append((first_field, None))
         for second_field in second_field_iterator:
-            matching_couples.append((None,second_field))
+            matching_couples.append((None, second_field))
         return matching_couples
 
-
         # don't forget to add the ones that didn't match to anybody.
 
-
-
-
-
-
     def __len__(self):
         return len(self.patient_groups)
 
